function [A_0n_Coeff, A_1n_Coeff, A_2n_Coeff] = A_Coefficients_Analytical(integrand_low,integrand_high,t_low,t_mid,t_up,t_eval,alpha)
%This function is not a part of the core software package and is not
%recommended to be used in the FDE solvers. This function is not called in
%any of the methods, but instead can be substituted with the
%'A_Coefficients()' function call to calculate the analytical answer to
%the convolution integral. This function was used in supplemental error 
% analysis only. 

syms tau

 Q_low =  ((tau - t_mid)/(t_low - t_mid)) * ((tau - t_up)/(t_low - t_up));

 Q_mid =  ((tau - t_low)/(t_mid - t_low)) * ((tau - t_up)/(t_mid - t_up));
        
 Q_up =  ((tau - t_low)/(t_up - t_low)) * ((tau - t_mid)/(t_up - t_mid));
 
%The core of the integral, this portion is the same for A_0, A_1, and A_2.
A_kernel = ((t_eval-tau)^(alpha-1));

%These lines combine the kernel with each appropriate interpolation
%function, combining both function handles into one:
A_0n_funct =  A_kernel*Q_low;
A_1n_funct =  A_kernel*Q_mid;
A_2n_funct =  A_kernel*Q_up;

%These lines compute the integral of the overall function, using the bounds
%input:
A_0n_Coeff = double(int(A_0n_funct,integrand_low,integrand_high));
A_1n_Coeff = double(int(A_1n_funct,integrand_low,integrand_high));        
A_2n_Coeff = double(int(A_2n_funct,integrand_low,integrand_high));
end


