function [L_j, L_jj] = Linear_Interp(t_j, t_jj)
% Linear_Interp is a supporting function for in FDE solver packages MF_PCL/MF_PCQ.
% This function implements a linear Lagrangian interpolation over the
% time-step from t_j to t_jj.
%INPUTS:
%   (1) t_j = (scalar number)  lower bound of interpolation
%   (2) t_jj = (scalar number) upper bound of interpolation (jj := j + 1) 
%OUTPUTS:
%   (1) L_j = (function handle @(tau)... ) lower-end interpolation function
%   (2) L_jj = (function handle @(tau)... ) upper-end interpolation function

L_j  = @(tau) (tau - t_jj) / (t_j - t_jj);
L_jj = @(tau) (tau - t_j) / (t_jj - t_j);
end
