% This is a test script to accompany thr FDE solver packages,
% MF_PCL/MF_PCQ. This script will present an example of how to use the
% packages and present one of the example fde's present in [1].
%
%[1] T. B. Nugyen and B. Jang, A high-order predictor-corrector method for
%    solving nonlinear differential equations of fractional order, 
%    Fractional Calculus and Applied Analysis, vol. 20, No. 2, pp. 447476, 2017.
% 
clear all;
close all;
clc;
%INPUTS:
alpha = 0.5;
fdefun = @(t,y) (40320/gamma(9-alpha))*t^(8-alpha) - 3*(gamma(5+alpha/2)/gamma(5-alpha/2))*t^(4-alpha/2) + 9/4*gamma(alpha+1) + (3/2*t^(alpha/2)-t^4)^3-y^(3/2);
t0 = 0;
t_final = 1;
y0 = [0,0];
tfinal = 1;
h = 0.05;

%Call the 2nd order method, MF_PCL:
[T,Y_PCL] = MF_PCL(alpha,fdefun,t0,tfinal,y0,h);

%Call the 3rd order method, MF_PCQ:
[T,Y_PCQ] = MF_PCQ(alpha,fdefun,t0,tfinal,y0,h);

%Call the original Method, ABM:
[T,Y_ABM] = fde12(alpha,fdefun,t0,tfinal,y0,h);

%Calculate True Solution:
i = 1;
    for t = t0:h:tfinal
        True_Solution(i) = t^8 - 3*t^(4+alpha/2)+9/4*t^alpha; %Change depending on Eq being used!
        i = i +1;
    end
figure(1)
title('Comparison of Competing Methods')
plot(T,Y_PCL);
hold on;
plot(T,Y_PCQ);
hold on;
plot(T,Y_ABM);
hold on;
plot(T,True_Solution);
legend('MF-PCL', 'MF-PCQ', 'ABM', 'Exact Solution')
xlabel('time, (T)')
ylabel('Solution, (Y)')