function [Q_low, Q_mid, Q_up] = Quadratic_Interp(t_low,t_mid,t_up)
% Quadratic_Interp is a supporting function in the FDE solver packages MF_PCL/MF_PCQ.
% This function implements a quadratic Lagrangian interpolation over the
% time-step from t_low to t_high.
%INPUTS:
%   (1) t_low  = (scalar number)  lower bound of interpolation
%   (2) t_mid  = (scalar number) middle value of interpolation
%   (3) t_high = (scalar number) upper value of interpolation
%OUTPUTS:
%   (1) Q_low = (function handle @(tau)... ) lower-end interpolation function
%   (2) Q_mid = (function handle @(tau)... ) middle interpolation function
%   (3) Q_up = (function handle @(tau)... ) upper-end interpolation function
 
 Q_low = @(tau) ((tau - t_mid)/(t_low - t_mid)) .* ((tau - t_up)/(t_low - t_up));

 Q_mid = @(tau) ((tau - t_low)/(t_mid - t_low)) .* ((tau - t_up)/(t_mid - t_up));
        
 Q_up = @(tau) ((tau - t_low)/(t_up - t_low)) .* ((tau - t_mid)/(t_up - t_mid));

end