function IC = calculate_IC(y0, alpha, t_eval)
% calculate_IC is a supporting function in the FDE solver packages,
% MF_PCL/MF_PCQ. This function calculates the g term relating to the initial
% condition data. It is calculated according to [1]. 
% 
%INPUTS:
%  (1) y0: (vector/ array of scalars) y0 should be of length m, defined as
%           m = ceiling(alpha). The terms of y0 are the values of [y(0),
%           y'(0), y''(0), ..., y^(m-1)] in this order.
%  (2) alpha: (scalar) order of the FDE. alpha > 0.
%  (3) t_eval: (scalar) the time that g is being evaluated at. 
%OUTPUTS:
%  (1) IC: (scalar) value of g evaluated at the time specified.
% 
% %%[1] T. B. Nugyen and B. Jang, A high-order predictor-corrector method for
%    solving nonlinear differential equations of fractional order, 
%    Fractional Calculus and Applied Analysis, vol. 20, No. 2, pp. 447476, 2017. 

g = 0;
m = ceil(alpha);

for k = 0:m-1
    g = g + y0(k+1)*(t_eval^k)/factorial(k);   
end

IC = g;
end